﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Infragistics.Web.UI.ListControls;
using System.Data.Common;

public partial class MVWebDropdown : System.Web.UI.UserControl
{
  public string Value
  {
    get
    {
      string str = "";

      foreach( DropDownItem ddi in ctlMVWebDropdown.SelectedItems )
        str += ddi.Value;

      return str;
    }
  }

  //****************************************************************************************************
  //  Method Name:	Page_Load
  /// <summary>             	Description:	Handles the page load.</summary>
  /// <param name="sender"> 	Parameter:		sender	Type:	object</param>
  /// <param name="e">      	Parameter:		e     	Type:	System.EventArgs</param>
  //****************************************************************************************************
  protected void Page_Load ( object sender, EventArgs e )
  {    
      LoadJavaScript();   
  }


  //****************************************************************************************************
  //  Method Name:	LoadJavaScript
  /// <summary> 	Description:	Loads the necessary javascript.</summary>
  //****************************************************************************************************
  private void LoadJavaScript ()
  {
    try
    {
      string clearAll = "javascript:"  + ctlMVWebDropdown.ClientID + "_ClearAll();";
      string selectAll = "javascript:" + ctlMVWebDropdown.ClientID + "_SelectAll();";

      this.ctlClearAll.Attributes.Add( "href", clearAll );
      this.ctlSelectAll.Attributes.Add( "href", selectAll );

      ctlMVWebDropdown.ClientEvents.DropDownOpening = this.ID + "_OnDropDownOpening";

      RegisterClientScript();
    }
    catch (Exception ex)
    {
      throw new Exception( "Unable to load javascript: " + ex.Message );
    }
  }

  //****************************************************************************************************
  //  Method Name:	RegisterClientScript
  /// <summary> 	Description:	Registers the needed javascript for the multivalue dropdown.</summary>
  //****************************************************************************************************
  private void RegisterClientScript ()
  {
    string mvId = ctlMVWebDropdown.ClientID;

    if( !Page.ClientScript.IsClientScriptBlockRegistered( mvId ) )
    {

      string scriptBlock = "function " + mvId + "_ClearAll()" + "{ " +
          "var dropDown = $find('" + mvId + "'); " +
              "var len = dropDown.get_items().get_length(); " +
              "for (var i = 0; i < len; i++) { " +
              "  var item = dropDown.get_items().getItem(i); " +
              "  if (item != null) { " +
              "    item.get_element().childNodes[0].checked = false; " +
              "    item.unselect(); " +
              "  } " +
              "} " +
              "dropDown.set_currentValue('',true); } ";

      scriptBlock += "function " + mvId + "_SelectAll()" + "{ " +
          "var dropDown = $find('" + mvId + "'); " +
              "var len = dropDown.get_items().get_length(); " +
              "for (var i = 0; i < len; i++) { " +
              "  var item = dropDown.get_items().getItem(i); " +
              "  if (item != null) { " +
              "    item.select(); " +
              "    item.get_element().childNodes[0].checked = true; " +
              "  } " +
              "} " +
              "dropDown.set_currentValue('All',true); }";

      scriptBlock += "function " + this.ID + "_Toggle() { " +
                        " var control = $find('" + this.ID + "_ctlMVWebDropdown');" +
                        " var value =  control.get_enabled() == true ? false: true;" +
                        " control.set_enabled(value);}"+Environment.NewLine;

      scriptBlock += "function " + this.ID + "_OnDropDownOpening(sender, e){" +
                     "var pageHeight = document.body.clientHeight;" +Environment.NewLine+
                     "var obj = document.getElementById ('" + mvId+"');" + Environment.NewLine +
                     "var pos = findPosY(obj) + 300; " + Environment.NewLine +
                     "var diff = pageHeight - pos; " +Environment.NewLine+
                     "if (diff < 1) sender.dropDownOrientation ='TopLeft'; " +Environment.NewLine+
                     "else sender.dropDownOrientation ='BottomLeft';}";

      Page.ClientScript.RegisterClientScriptBlock( this.Page.GetType(), mvId, scriptBlock, true );
    }
  }

  //****************************************************************************************************
  //  Method Name:	LoadControl
  /// <summary>                      	Description:	Loads the control with information.</summary>
  /// <param name="dataSource">      	Parameter:		dataSource     	Type:	string</param>
  /// <param name="storedProcedure"> 	Parameter:		storedProcedure	Type:	string</param>
  //****************************************************************************************************
  public void LoadDropdown (Dictionary<string,string> data )
  {
    try
    {
      ctlMVWebDropdown.Items.Clear();

      int i = 0;
      foreach( string key in data.Keys )
      {
        ctlMVWebDropdown.Items.Add( new DropDownItem( key, data [key] ) );
        ctlMVWebDropdown.Items [i].Selected = true;
      }

      ctlMVWebDropdown.CurrentValue = "All";
    }
    catch( Exception ex )
    {
      throw new Exception( "Unable to load the control: " + ex.Message );
    }
  }
}
